#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 http-streams
version:              0.8.9.9
visibility:           public
id:                   http-streams-0.8.9.9-6AIXF5IRDtLFlBEbgDooTh
key:                  http-streams-0.8.9.9-6AIXF5IRDtLFlBEbgDooTh
license:              BSD-3-Clause
copyright:            © 2012-2023 Athae Eredh Siniath and Others
maintainer:           Andrew Cowie <istathar@gmail.com>
author:               Andrew Cowie <istathar@gmail.com>
stability:            experimental
homepage:             https://github.com/aesiniath/http-streams/
synopsis:             An HTTP client using io-streams
description:
    An HTTP client, using the Snap Framework'\''s '\''io-streams'\'' library to
    handle the streaming IO. The API is optimized for ease of use for the
    rather common case of code needing to query web services and deal with
    the result.

    The library is exported in a single module; see "Network.Http.Client"
    for full documentation.

category:             Web, IO-Streams
abi:                  3dc27f63b29f1d6048f0bac91a2522d2
exposed:              True
exposed-modules:
    Network.Http.Client Network.Http.Connection
    Network.Http.Inconvenience Network.Http.ResponseParser

hidden-modules:       Network.Http.Utilities
import-dirs:          /usr/lib/ghc-9.6.6/site-local/http-streams-0.8.9.9
library-dirs:         /usr/lib/ghc-9.6.6/site-local/http-streams-0.8.9.9
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/http-streams-0.8.9.9
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-http-streams
hs-libraries:         HShttp-streams-0.8.9.9-6AIXF5IRDtLFlBEbgDooTh
depends:
    HsOpenSSL-0.11.7.9-9h2AmtvUUOpArhcntkthRO
    aeson-2.2.1.0-3GuQND0ICGU2GYmExSDp1b
    attoparsec-0.14.4-FIfeiNzOKYm3sEc1QPF51Z
    attoparsec-aeson-2.2.0.0-BA0hXDi6heL1lJja6ufLjW base-4.18.2.1
    base64-bytestring-1.2.1.0-6srVB7ZKmzD1HZV2AV5j9d
    blaze-builder-0.4.4.1-IalnSqFtizaBKkEQN83UwH bytestring-0.11.5.3
    case-insensitive-1.2.1.0-HFTLAepm1u61gRs0sAANH directory-1.3.8.5
    filepath-1.4.300.1 http-common-0.8.3.4-FSgWyxxGejp4mndfdfxi6X
    io-streams-1.5.2.2-Fu0yXFNFykK48vHTxDZPZi mtl-2.3.1
    network-3.1.4.0-LsWsY6caX6uCNLTGwySDR3
    network-uri-2.6.4.2-3U0FvLc2coZ6tqjF5PGDly
    openssl-streams-1.2.3.0-DhK3P2sAQnw1UatztN4rHv text-2.0.2
    transformers-0.6.1.0
    unordered-containers-0.2.20.1-I6eyTXb69D2BhxejMtPouo

haddock-interfaces:
    /usr/share/doc/haskell-http-streams/html/http-streams.haddock

haddock-html:         /usr/share/doc/haskell-http-streams/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

